@@ -1,5 +1,5 @@
 package App::CharmKit::Command::clean;
-$App::CharmKit::Command::clean::VERSION = '0.003_1';
+$App::CharmKit::Command::clean::VERSION = '0.003_2';
 # ABSTRACT: Cleanses project
 
 
@@ -7,6 +7,7 @@ use App::CharmKit -command;
 use Path::Tiny;
 
 use Moo;
+with 'App::CharmKit::Role::Clean';
 use namespace::clean;
 
 sub opt_spec {
@@ -18,10 +19,14 @@ sub usage_desc {'%c clean'}
 
 sub execute {
     my ($self, $opt, $args) = @_;
-    my $path = path('.');
-    if ($path->child('fatlib')->exists) {
-        $path->child('fatlib')->remove_tree;
+
+    my @paths_to_rm = path('tests')->children(qr/\.test/);
+    if (path('fatlib')->exists) {
+        push @paths_to_rm, path('fatlib');
     }
+    push @paths_to_rm, path('hooks')->children;
+    $self->clean(\@paths_to_rm);
+    print("Finished cleaning project.\n");
 }
 
 1;
@@ -38,7 +43,7 @@ App::CharmKit::Command::clean - Cleanses project
 
 =head1 VERSION
 
-version 0.003_1
+version 0.003_2
 
 =head1 SYNOPSIS
 
